@@ -87,12 +87,16 @@ func main() {
 	configRules = append(configRules, rules.GrafanaCloudApiToken())
 	configRules = append(configRules, rules.GrafanaServiceAccountToken())
 	configRules = append(configRules, rules.Hashicorp())
+	configRules = append(configRules, rules.HashicorpField())
 	configRules = append(configRules, rules.Heroku())
 	configRules = append(configRules, rules.HubSpot())
+	configRules = append(configRules, rules.HuggingFaceAccessToken())
+	configRules = append(configRules, rules.HuggingFaceOrganizationApiToken())
 	configRules = append(configRules, rules.Intercom())
 	configRules = append(configRules, rules.JFrogAPIKey())
 	configRules = append(configRules, rules.JFrogIdentityToken())
 	configRules = append(configRules, rules.JWT())
+	configRules = append(configRules, rules.JWTBase64())
 	configRules = append(configRules, rules.KrakenAccessToken())
 	configRules = append(configRules, rules.KucoinAccessToken())
 	configRules = append(configRules, rules.KucoinSecretKey())
@@ -133,6 +137,7 @@ func main() {
 	configRules = append(configRules, rules.RapidAPIAccessToken())
 	configRules = append(configRules, rules.ReadMe())
 	configRules = append(configRules, rules.RubyGemsAPIToken())
+	configRules = append(configRules, rules.ScalingoAPIToken())
 	configRules = append(configRules, rules.SendbirdAccessID())
 	configRules = append(configRules, rules.SendbirdAccessToken())
 	configRules = append(configRules, rules.SendGridAPIToken())
@@ -178,6 +183,7 @@ func main() {
 	configRules = append(configRules, rules.YandexAccessToken())
 	configRules = append(configRules, rules.ZendeskSecretKey())
 	configRules = append(configRules, rules.GenericCredential())
+	configRules = append(configRules, rules.InfracostAPIToken())
 
 	// ensure rules have unique ids
 	ruleLookUp := make(map[string]config.Rule)
