@@ -11,9 +11,8 @@ func Atlassian() *config.Rule {
 		Description: "Atlassian API token",
 		RuleID:      "atlassian-api-token",
 		Regex: generateSemiGenericRegex([]string{
-			"atlassian", "confluence", "jira"}, alphaNumeric("24")),
-		SecretGroup: 1,
-		Keywords:    []string{"atlassian", "confluence", "jira"},
+			"atlassian", "confluence", "jira"}, alphaNumeric("24"), true),
+		Keywords: []string{"atlassian", "confluence", "jira"},
 	}
 
 	// validate
