@@ -10,9 +10,8 @@ func Beamer() *config.Rule {
 	r := config.Rule{
 		Description: "Beamer API token",
 		RuleID:      "beamer-api-token",
-		SecretGroup: 1,
 		Regex: generateSemiGenericRegex([]string{"beamer"},
-			`b_[a-z0-9=_\-]{44}`),
+			`b_[a-z0-9=_\-]{44}`, true),
 		Keywords: []string{"beamer"},
 	}
 
