@@ -10,8 +10,7 @@ func ConfluentSecretKey() *config.Rule {
 	r := config.Rule{
 		RuleID:      "confluent-secret-key",
 		Description: "Confluent Secret Key",
-		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("64")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("64"), true),
 		Keywords: []string{
 			"confluent",
 		},
@@ -29,8 +28,8 @@ func ConfluentAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "confluent-access-token",
 		Description: "Confluent Access Token",
-		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("16")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"confluent"}, alphaNumeric("16"), true),
+
 		Keywords: []string{
 			"confluent",
 		},
