@@ -11,9 +11,8 @@ func Contentful() *config.Rule {
 		Description: "Contentful delivery API token",
 		RuleID:      "contentful-delivery-api-token",
 		Regex: generateSemiGenericRegex([]string{"contentful"},
-			alphaNumericExtended("43")),
-		SecretGroup: 1,
-		Keywords:    []string{"contentful"},
+			alphaNumericExtended("43"), true),
+		Keywords: []string{"contentful"},
 	}
 
 	// validate
