@@ -11,8 +11,7 @@ func DatadogtokenAccessToken() *config.Rule {
 		RuleID:      "datadog-access-token",
 		Description: "Datadog Access Token",
 		Regex: generateSemiGenericRegex([]string{"datadog"},
-			alphaNumeric("40")),
-		SecretGroup: 1,
+			alphaNumeric("40"), true),
 		Keywords: []string{
 			"datadog",
 		},
