@@ -9,8 +9,7 @@ func DigitalOceanPAT() *config.Rule {
 	r := config.Rule{
 		Description: "DigitalOcean Personal Access Token",
 		RuleID:      "digitalocean-pat",
-		SecretGroup: 1,
-		Regex:       generateUniqueTokenRegex(`dop_v1_[a-f0-9]{64}`),
+		Regex:       generateUniqueTokenRegex(`dop_v1_[a-f0-9]{64}`, true),
 		Keywords:    []string{"dop_v1_"},
 	}
 
@@ -24,9 +23,9 @@ func DigitalOceanOAuthToken() *config.Rule {
 	r := config.Rule{
 		Description: "DigitalOcean OAuth Access Token",
 		RuleID:      "digitalocean-access-token",
-		SecretGroup: 1,
-		Regex:       generateUniqueTokenRegex(`doo_v1_[a-f0-9]{64}`),
-		Keywords:    []string{"doo_v1_"},
+
+		Regex:    generateUniqueTokenRegex(`doo_v1_[a-f0-9]{64}`, true),
+		Keywords: []string{"doo_v1_"},
 	}
 
 	tps := []string{
@@ -39,9 +38,9 @@ func DigitalOceanRefreshToken() *config.Rule {
 	r := config.Rule{
 		Description: "DigitalOcean OAuth Refresh Token",
 		RuleID:      "digitalocean-refresh-token",
-		SecretGroup: 1,
-		Regex:       generateUniqueTokenRegex(`dor_v1_[a-f0-9]{64}`),
-		Keywords:    []string{"dor_v1_"},
+
+		Regex:    generateUniqueTokenRegex(`dor_v1_[a-f0-9]{64}`, true),
+		Keywords: []string{"dor_v1_"},
 	}
 
 	tps := []string{
