@@ -19,8 +19,7 @@ func GenericCredential() *config.Rule {
 			"password",
 			"auth",
 			"access",
-		}, `[0-9a-z\-_.=]{10,150}`),
-		SecretGroup: 1,
+		}, `[0-9a-z\-_.=]{10,150}`, true),
 		Keywords: []string{
 			"key",
 			"api",
