@@ -11,8 +11,8 @@ func GitterAccessToken() *config.Rule {
 		RuleID:      "gitter-access-token",
 		Description: "Gitter Access Token",
 		Regex: generateSemiGenericRegex([]string{"gitter"},
-			alphaNumericExtendedShort("40")),
-		SecretGroup: 1,
+			alphaNumericExtendedShort("40"), true),
+
 		Keywords: []string{
 			"gitter",
 		},
