@@ -10,8 +10,8 @@ func GoCardless() *config.Rule {
 	r := config.Rule{
 		RuleID:      "gocardless-api-token",
 		Description: "GoCardless API token",
-		Regex:       generateSemiGenericRegex([]string{"gocardless"}, `live_(?i)[a-z0-9\-_=]{40}`),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"gocardless"}, `live_(?i)[a-z0-9\-_=]{40}`, true),
+
 		Keywords: []string{
 			"live_",
 			"gocardless",
