@@ -10,9 +10,9 @@ func Intercom() *config.Rule {
 	r := config.Rule{
 		Description: "Intercom API Token",
 		RuleID:      "intercom-api-key",
-		Regex:       generateSemiGenericRegex([]string{"intercom"}, alphaNumericExtended("60")),
-		SecretGroup: 1,
-		Keywords:    []string{"intercom"},
+		Regex:       generateSemiGenericRegex([]string{"intercom"}, alphaNumericExtended("60"), true),
+
+		Keywords: []string{"intercom"},
 	}
 
 	// validate
