@@ -10,8 +10,8 @@ func MailGunPrivateAPIToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "mailgun-private-api-token",
 		Description: "Mailgun private API token",
-		Regex:       generateSemiGenericRegex([]string{"mailgun"}, `key-[a-f0-9]{32}`),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"mailgun"}, `key-[a-f0-9]{32}`, true),
+
 		Keywords: []string{
 			"mailgun",
 		},
@@ -29,8 +29,8 @@ func MailGunPubAPIToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "mailgun-pub-key",
 		Description: "Mailgun public validation key",
-		Regex:       generateSemiGenericRegex([]string{"mailgun"}, `pubkey-[a-f0-9]{32}`),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"mailgun"}, `pubkey-[a-f0-9]{32}`, true),
+
 		Keywords: []string{
 			"mailgun",
 		},
@@ -48,8 +48,8 @@ func MailGunSigningKey() *config.Rule {
 	r := config.Rule{
 		RuleID:      "mailgun-signing-key",
 		Description: "Mailgun webhook signing key",
-		Regex:       generateSemiGenericRegex([]string{"mailgun"}, `[a-h0-9]{32}-[a-h0-9]{8}-[a-h0-9]{8}`),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"mailgun"}, `[a-h0-9]{32}-[a-h0-9]{8}-[a-h0-9]{8}`, true),
+
 		Keywords: []string{
 			"mailgun",
 		},
