@@ -10,9 +10,9 @@ func MapBox() *config.Rule {
 	r := config.Rule{
 		Description: "MapBox API token",
 		RuleID:      "mapbox-api-token",
-		Regex:       generateSemiGenericRegex([]string{"mapbox"}, `pk\.[a-z0-9]{60}\.[a-z0-9]{22}`),
-		SecretGroup: 1,
-		Keywords:    []string{"mapbox"},
+		Regex:       generateSemiGenericRegex([]string{"mapbox"}, `pk\.[a-z0-9]{60}\.[a-z0-9]{22}`, true),
+
+		Keywords: []string{"mapbox"},
 	}
 
 	// validate
