@@ -14,8 +14,8 @@ func NewRelicUserID() *config.Rule {
 			"new-relic",
 			"newrelic",
 			"new_relic",
-		}, `NRAK-[a-z0-9]{27}`),
-		SecretGroup: 1,
+		}, `NRAK-[a-z0-9]{27}`, true),
+
 		Keywords: []string{
 			"NRAK",
 		},
@@ -37,8 +37,8 @@ func NewRelicUserKey() *config.Rule {
 			"new-relic",
 			"newrelic",
 			"new_relic",
-		}, alphaNumeric("64")),
-		SecretGroup: 1,
+		}, alphaNumeric("64"), true),
+
 		Keywords: []string{
 			"new-relic",
 			"newrelic",
@@ -62,8 +62,8 @@ func NewRelicBrowserAPIKey() *config.Rule {
 			"new-relic",
 			"newrelic",
 			"new_relic",
-		}, `NRJS-[a-f0-9]{19}`),
-		SecretGroup: 1,
+		}, `NRJS-[a-f0-9]{19}`, true),
+
 		Keywords: []string{
 			"NRJS-",
 		},
