@@ -11,8 +11,8 @@ func OktaAccessToken() *config.Rule {
 		RuleID:      "okta-access-token",
 		Description: "Okta Access Token",
 		Regex: generateSemiGenericRegex([]string{"okta"},
-			alphaNumericExtended("42")),
-		SecretGroup: 1,
+			alphaNumericExtended("42"), true),
+
 		Keywords: []string{
 			"okta",
 		},
