@@ -12,9 +12,9 @@ func PlaidAccessID() *config.Rule {
 	r := config.Rule{
 		RuleID:      "plaid-client-id",
 		Description: "Plaid Client ID",
-		Regex:       generateSemiGenericRegex([]string{"plaid"}, alphaNumeric("24")),
-		SecretGroup: 1,
-		Entropy:     3.5,
+		Regex:       generateSemiGenericRegex([]string{"plaid"}, alphaNumeric("24"), true),
+
+		Entropy: 3.5,
 		Keywords: []string{
 			"plaid",
 		},
@@ -32,9 +32,9 @@ func PlaidSecretKey() *config.Rule {
 	r := config.Rule{
 		RuleID:      "plaid-secret-key",
 		Description: "Plaid Secret key",
-		Regex:       generateSemiGenericRegex([]string{"plaid"}, alphaNumeric("30")),
-		SecretGroup: 1,
-		Entropy:     3.5,
+		Regex:       generateSemiGenericRegex([]string{"plaid"}, alphaNumeric("30"), true),
+
+		Entropy: 3.5,
 		Keywords: []string{
 			"plaid",
 		},
@@ -53,8 +53,8 @@ func PlaidAccessToken() *config.Rule {
 		RuleID:      "plaid-api-token",
 		Description: "Plaid API Token",
 		Regex: generateSemiGenericRegex([]string{"plaid"},
-			fmt.Sprintf("access-(?:sandbox|development|production)-%s", hex8_4_4_4_12())),
-		SecretGroup: 1,
+			fmt.Sprintf("access-(?:sandbox|development|production)-%s", hex8_4_4_4_12()), true),
+
 		Keywords: []string{
 			"plaid",
 		},
