@@ -10,8 +10,8 @@ func SentryAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "sentry-access-token",
 		Description: "Sentry Access Token",
-		Regex:       generateSemiGenericRegex([]string{"sentry"}, hex("64")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"sentry"}, hex("64"), true),
+
 		Keywords: []string{
 			"sentry",
 		},
