@@ -10,8 +10,8 @@ func TravisCIAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "travisci-access-token",
 		Description: "Travis CI Access Token",
-		Regex:       generateSemiGenericRegex([]string{"travis"}, alphaNumeric("22")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"travis"}, alphaNumeric("22"), true),
+
 		Keywords: []string{
 			"travis",
 		},
