@@ -10,8 +10,7 @@ func TwitterAPIKey() *config.Rule {
 	r := config.Rule{
 		Description: "Twitter API Key",
 		RuleID:      "twitter-api-key",
-		Regex:       generateSemiGenericRegex([]string{"twitter"}, alphaNumeric("25")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"twitter"}, alphaNumeric("25"), true),
 		Keywords:    []string{"twitter"},
 	}
 
@@ -27,8 +26,7 @@ func TwitterAPISecret() *config.Rule {
 	r := config.Rule{
 		Description: "Twitter API Secret",
 		RuleID:      "twitter-api-secret",
-		Regex:       generateSemiGenericRegex([]string{"twitter"}, alphaNumeric("50")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"twitter"}, alphaNumeric("50"), true),
 		Keywords:    []string{"twitter"},
 	}
 
@@ -44,9 +42,9 @@ func TwitterBearerToken() *config.Rule {
 	r := config.Rule{
 		Description: "Twitter Bearer Token",
 		RuleID:      "twitter-bearer-token",
-		Regex:       generateSemiGenericRegex([]string{"twitter"}, "A{22}[a-zA-Z0-9%]{80,100}"),
-		SecretGroup: 1,
-		Keywords:    []string{"twitter"},
+		Regex:       generateSemiGenericRegex([]string{"twitter"}, "A{22}[a-zA-Z0-9%]{80,100}", true),
+
+		Keywords: []string{"twitter"},
 	}
 
 	// validate
@@ -61,8 +59,7 @@ func TwitterAccessToken() *config.Rule {
 	r := config.Rule{
 		Description: "Twitter Access Token",
 		RuleID:      "twitter-access-token",
-		Regex:       generateSemiGenericRegex([]string{"twitter"}, "[0-9]{15,25}-[a-zA-Z0-9]{20,40}"),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"twitter"}, "[0-9]{15,25}-[a-zA-Z0-9]{20,40}", true),
 		Keywords:    []string{"twitter"},
 	}
 
@@ -78,8 +75,7 @@ func TwitterAccessSecret() *config.Rule {
 	r := config.Rule{
 		Description: "Twitter Access Secret",
 		RuleID:      "twitter-access-secret",
-		Regex:       generateSemiGenericRegex([]string{"twitter"}, alphaNumeric("45")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"twitter"}, alphaNumeric("45"), true),
 		Keywords:    []string{"twitter"},
 	}
 
