@@ -10,7 +10,7 @@ func VaultServiceToken() *config.Rule {
 	r := config.Rule{
 		Description: "Vault Service Token",
 		RuleID:      "vault-service-token",
-		Regex:       generateUniqueTokenRegex(`hvs\.[a-z0-9_-]{90,100}`),
+		Regex:       generateUniqueTokenRegex(`hvs\.[a-z0-9_-]{90,100}`, true),
 		Keywords:    []string{"hvs"},
 	}
 
@@ -26,7 +26,7 @@ func VaultBatchToken() *config.Rule {
 	r := config.Rule{
 		Description: "Vault Batch Token",
 		RuleID:      "vault-batch-token",
-		Regex:       generateUniqueTokenRegex(`hvb\.[a-z0-9_-]{138,212}`),
+		Regex:       generateUniqueTokenRegex(`hvb\.[a-z0-9_-]{138,212}`, true),
 		Keywords:    []string{"hvb"},
 	}
 
