@@ -11,8 +11,7 @@ func YandexAWSAccessToken() *config.Rule {
 		RuleID:      "yandex-aws-access-token",
 		Description: "Yandex AWS Access Token",
 		Regex: generateSemiGenericRegex([]string{"yandex"},
-			`YC[a-zA-Z0-9_\-]{38}`),
-		SecretGroup: 1,
+			`YC[a-zA-Z0-9_\-]{38}`, true),
 		Keywords: []string{
 			"yandex",
 		},
@@ -32,8 +31,8 @@ func YandexAPIKey() *config.Rule {
 		RuleID:      "yandex-api-key",
 		Description: "Yandex API Key",
 		Regex: generateSemiGenericRegex([]string{"yandex"},
-			`AQVN[A-Za-z0-9_\-]{35,38}`),
-		SecretGroup: 1,
+			`AQVN[A-Za-z0-9_\-]{35,38}`, true),
+
 		Keywords: []string{
 			"yandex",
 		},
@@ -53,8 +52,8 @@ func YandexAccessToken() *config.Rule {
 		RuleID:      "yandex-access-token",
 		Description: "Yandex Access Token",
 		Regex: generateSemiGenericRegex([]string{"yandex"},
-			`t1\.[A-Z0-9a-z_-]+[=]{0,2}\.[A-Z0-9a-z_-]{86}[=]{0,2}`),
-		SecretGroup: 1,
+			`t1\.[A-Z0-9a-z_-]+[=]{0,2}\.[A-Z0-9a-z_-]{86}[=]{0,2}`, true),
+
 		Keywords: []string{
 			"yandex",
 		},
