@@ -10,8 +10,7 @@ func ZendeskSecretKey() *config.Rule {
 	r := config.Rule{
 		RuleID:      "zendesk-secret-key",
 		Description: "Zendesk Secret Key",
-		Regex:       generateSemiGenericRegex([]string{"zendesk"}, alphaNumeric("40")),
-		SecretGroup: 1,
+		Regex:       generateSemiGenericRegex([]string{"zendesk"}, alphaNumeric("40"), true),
 		Keywords: []string{
 			"zendesk",
 		},
